@@ -1,5 +1,5 @@
 from . import core
-from .api import (key, city, cities, discovery, post, request,
+from .api import (key, city, cities, dev, discovery, post, request,
                   requests, services, token)
 from .cities import CityNotFound
 from .core import Three
