@@ -153,8 +153,13 @@ class Three(object):
         if url:
             data = requests.get(url).content
         elif self.discovery_url:
-            # Spec calls for discovery always allowing JSON
-            data = requests.get(self.discovery_url).json
+            response = requests.get(self.discovery_url)
+            if self.format == 'xml':
+                # Because, SF doesn't follow the spec.
+                data = xml(response.text)
+            else:
+                # Spec calls for discovery always allowing JSON.
+                data = response.json
         else:
             data = self.get('discovery')
         return data
@@ -203,13 +208,19 @@ class Three(object):
 
         >>> t = Three('api.city.gov')
         >>> t.post('123', address='123 Any St', name='Zach Williams',
-        ...        phone='555-5555', description='My issue description'.)
+        ...        phone='555-5555', description='My issue description.',
+        ...        media=open('photo.png', 'rb'))
         {'successful': {'request': 'post'}}
         """
         kwargs['code'] = code
         kwargs = self._post_keywords(**kwargs)
+        media = kwargs.pop('media', None)
+        if media:
+            files = {'media': media}
+        else:
+            files = None
         url = self._create_path('requests')
-        self.request = requests.post(url, data=kwargs)
+        self.request = requests.post(url, data=kwargs, files=files)
         content = self.request.content
         if self.request.status_code == 200:
             conversion = True
@@ -220,6 +231,8 @@ class Three(object):
     def _post_keywords(self, **kwargs):
         """Configure keyword arguments for Open311 POST requests."""
         code = kwargs.pop('code')
+        if self.jurisdiction and 'jurisdiction_id' not in kwargs:
+            kwargs['jurisdiction_id'] = self.jurisdiction
         if 'address' in kwargs:
             address = kwargs.pop('address')
             kwargs['address_string'] = address
